import { Page, Dialog } from 'puppeteer-core';
import Generic from './Generic';
import { ICommand } from './Snapshots';
import Puth from './Puth';
import PuthContextPlugin from './PuthContextPlugin';
import { Handler, WildcardHandler } from 'mitt';
import Return from './Context/Return';
import { PuthBrowser } from "./HandlesBrowsers";
type ContextEvents = {
    'call': any;
    'get': any;
    'set': any;
    'delete': any;
    'destroying': any;
    'browser:connected': {
        browser: PuthBrowser;
    };
    'browser:disconnected': {
        browser: PuthBrowser;
    };
    'page:created': {
        browser: PuthBrowser;
        page: Page;
    };
    'page:closed': {
        browser: PuthBrowser;
        page: Page;
    };
};
declare class Context extends Generic {
    private readonly id;
    private readonly type;
    private readonly emitter;
    private readonly puth;
    private options;
    private plugins;
    browsers: PuthBrowser[];
    private eventFunctions;
    private readonly createdAt;
    caches: {
        snapshot: {
            lastHtml: string;
        };
        dialog: Map<Page, Dialog>;
    };
    private cleanupCallbacks;
    constructor(puth: Puth, options?: any);
    setup(): Promise<void>;
    connectBrowser(options: any): Promise<import("puppeteer-core").Browser>;
    createBrowser(options?: any): Promise<PuthBrowser>;
    isDev(): boolean;
    _trackBrowser(browser: PuthBrowser | undefined): Promise<void>;
    destroy(options?: any): Promise<boolean>;
    destroyBrowserByBrowser(browser: any): Promise<void>;
    private removeBrowser;
    isPageBlockedByDialog(page: any): boolean;
    _trackPage(page: any): void;
    getSnapshotsByType(type: any): Return;
    registerEventListenerOn(object: any, event: any, func: any): void;
    removeEventListenersFrom(object: any): void;
    unregisterAllEventListeners(): void;
    _cleanPage(page: any): Promise<void>;
    testFailed(): void;
    exception(exception: any): void;
    testSuccess(): void;
    saveContextSnapshot(options: any): Promise<void>;
    shouldSnapshot(func?: () => any): any;
    createCommandInstance(packet: any, on: any): Promise<ICommand | undefined>;
    callAll(calls: any): Promise<any[]>;
    callAny(calls: any): Promise<any[]>;
    callRace(calls: any): Promise<any[]>;
    call(packet: any): Promise<any>;
    handleCallApply(packet: any, page: any, command: any, on: any, func: any, parameters: any, expects?: any): Promise<any>;
    handleCallApplyAfter(packet: any, page: any, command: any, returnValue: any, expectation?: any): Promise<any>;
    resolveReturnValue(action: any, returnValue: any): any;
    private isObjectSerializable;
    private isValueSerializable;
    get(action: any): Promise<{
        id: string;
        type: string;
        represents: any;
    } | Return | {
        type: string;
        code: string;
        message: string;
    }>;
    set(action: any): Promise<{
        type: string;
        code: string;
        message: string;
    } | undefined>;
    delete(action: any): Promise<{
        type: string;
        code: string;
        message: string;
    } | undefined>;
    saveTemporaryFile(name: any, content: any): Promise<Return>;
    resolveOn(representation: any): Context | any;
    resolveIfCached(representation: any): any;
    getId(): string;
    getType(toLowerCase?: boolean): string;
    serialize(toLowerCase?: boolean): {
        id: string;
        type: string;
        represents: string;
        test: {
            name: string | undefined;
            status: "failed" | "success" | undefined;
        };
        group: string | undefined;
    };
    getTest(): {
        name: string | undefined;
        status: "failed" | "success" | undefined;
    };
    getGroup(): string | undefined;
    getPuth(): Puth;
    getPlugins(): PuthContextPlugin[];
    on<Key extends keyof ContextEvents>(type: Key, handler: Handler<ContextEvents[Key]>): void;
    on(type: '*', handler: WildcardHandler<ContextEvents>): void;
    off<Key extends keyof ContextEvents>(type: Key, handler: Handler<ContextEvents[Key]>): void;
    off(type: '*', handler: WildcardHandler<ContextEvents>): void;
    emit<Key extends keyof ContextEvents>(type: Key, event: ContextEvents[Key]): void;
    emit<Key extends keyof ContextEvents>(type: undefined extends ContextEvents[Key] ? Key : never): void;
    getTimeout(options?: any): any;
}
export default Context;
